@@ -21,19 +21,19 @@ class AttendanceManager(object):
     def open(self):
         return self.browser.open_attendance()
 
-    def today(self):
+    def history(self):
         timetable = self.get_attendance_timetable(dt.datetime.now().day)
         self.print_timetable(timetable)
 
     def print_timetable(self, timetable):
         texts = [
-            Color.get_colored(Color.BOLD, 'Work START:  ')
+            Color.get_colored(Color.BOLD, '出勤:     ')
             + ', '.join(timetable[0]),
-            Color.get_colored(Color.BOLD, 'Work END:    ')
+            Color.get_colored(Color.BOLD, '退勤:     ')
             + ', '.join(timetable[1]),
-            Color.get_colored(Color.BOLD, 'Break START: ')
+            Color.get_colored(Color.BOLD, '休憩開始: ')
             + ', '.join(timetable[2]),
-            Color.get_colored(Color.BOLD, 'Break END:   ')
+            Color.get_colored(Color.BOLD, '休憩終了: ')
             + ', '.join(timetable[3])
         ]
         print('================================')
